@@ -1,14 +1,14 @@
 #' Calculate Monte Carlo Oral Equivalent Dose
 #' 
 #' This functions converts a chemical plasma concetration to an oral equivalent
-#' dose using a concentration obtained from calc_mc_css.  
+#' dose using a concentration obtained from \code{\link{calc_mc_css}}.  
 #' 
 #' 
 #' All arguments after httkpop only apply if httkpop is set to TRUE and species
 #' to "Human".
 #' 
 #' When species is specified as rabbit, dog, or mouse, the function uses the
-#' appropriate physiological data(volumes and flows) but substitues human
+#' appropriate physiological data(volumes and flows) but substitutes human
 #' fraction unbound, partition coefficients, and intrinsic hepatic clearance.
 #' 
 #' Tissue concentrations are calculated for the pbtk model with oral infusion
@@ -16,7 +16,7 @@
 #' steady state plasma concentration and the tissue to plasma partition
 #' coefficient.
 #' 
-#' The six sets of plausible \emph{in vitro-in vivo} extrpolation (IVIVE)
+#' The six sets of plausible \emph{in vitro-in vivo} extrapolation (IVIVE)
 #' assumptions identified by Honda et al. (2019) are: \tabular{lrrrr}{
 #' \tab \emph{in vivo} Conc. \tab Metabolic Clearance \tab Bioactive Chemical
 #' Conc. \tab TK Statistic Used* \cr Honda1 \tab Veinous (Plasma) \tab
@@ -42,7 +42,7 @@
 #' @param output.units Units of dose, default of 'mgpkgpday' for mg/kg BW/ day or
 #' 'umolpkgpday' for umol/ kg BW/ day.
 #' @param which.quantile Which quantile from Monte Carlo steady-state
-#' simulation (calc_mc_css) is requested. Can be a vector. Note that 95th
+#' simulation (\code{\link{calc_mc_css}}) is requested. Can be a vector. Note that 95th
 #' concentration quantile is the same population as the 5th dose quantile. 
 #' @param species Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or
 #' default "Human").  
@@ -60,7 +60,7 @@
 #' Argument may be set to "Honda1" through "Honda6". If used, this function
 #' overwrites the tissue, restrictive.clearance, and plasma.binding arguments.
 #' See Details below for more information.
-#' @param ... Additional parameters passed to calc_mc_css for httkpop and
+#' @param ... Additional parameters passed to \code{\link{calc_mc_css}} for httkpop and
 #' variance of parameters.
 #' @return Equivalent dose in specified units, default of mg/kg BW/day.
 #' @author John Wambaugh
@@ -86,7 +86,7 @@
 #' 
 #' \dontrun{
 #' calc_mc_oral_equiv(0.1,chem.cas="34256-82-1",which.quantile=c(0.05,0.5,0.95),
-#'                    method='vi',samples=100,tissue='brain')
+#'        tissue='brain')
 #' }
 #' 
 #' @export calc_mc_oral_equiv
@@ -171,7 +171,7 @@ calc_mc_oral_equiv <- function(conc,
 	if (class(Css) == "try-error"){
     return(NA)
   }else{
-    return(dose)
+    return(set_httk_precision(dose))
   }
   
 }
