@@ -35,7 +35,7 @@
 #' @param days Length of the simulation.
 #' @param tsteps The number time steps per hour.
 #' @param daily.dose Total daily dose, mg/kg BW.
-#' @param dose Amount of a single dose, mg/kg BW.  Overwrites daily.dose.
+#' @param dose Amount of a single dose, mg/kg BW. 
 #' @param doses.per.day Number of doses per day.
 #' @param species Species desired (either "Rat", "Rabbit", "Dog", or default
 #' "Human").
@@ -99,7 +99,7 @@ solve_1comp <- function(chem.name = NULL,
                     days=10,
                     tsteps = 4, # tsteps is number of steps per hour
                     daily.dose = NULL,
-                    dose = 1, # Assume dose is in mg/kg BW/day  
+                    dose = NULL,  
                     doses.per.day=NULL,
                     initial.values=NULL,
                     plots=F,
