@@ -8,9 +8,9 @@
 #' of exposure, the concentration of gas inhaled, the period of a given 
 #' assumed cycle of exposure, and the duration of the exposure during that 
 #' period. Together, these arguments determine the forcings passed to the 
-#' ODE integrator. Forcings can also be specified manually, or effectively 
-#' turned off by setting exposure concentration to zero, if the user prefers
-#' to simulate dosing by other means. 
+#' ODE integrator. The "forcings" can also be specified manually, or 
+#' effectively turned off by setting exposure concentration to zero, if the
+#' user prefers to simulate dosing by other means. 
 #' 
 #' 
 #' This function solves for the amounts or concentrations in uM of a chemical
@@ -51,27 +51,28 @@
 #' be specified.
 #' @param dtxsid EPA's DSSTox Structure ID (\url{http://comptox.epa.gov/dashboard})  
 #' the chemical must be identified by either CAS, name, or DTXSIDs
-#' @param parameters Chemical parameters from parameterize_pbtk function,
-#' overrides chem.name and chem.cas.
+#' @param parameters Chemical parameters from parameterize_gas_pbtk (or other
+#' bespoke) function, overrides chem.name and chem.cas.
 #' @param times Optional time sequence for specified number of days.  Dosing
 #' sequence begins at the beginning of times.
 #' @param days Length of the simulation.
 #' @param tsteps The number of time steps per hour.
 #' @param daily.dose Total daily dose, mg/kg BW.
 #' @param doses.per.day Number of doses per day.
-#' @param dose Amount of a single dose, mg/kg BW. Overwrites daily.dose.
+#' @param dose Amount of a single dose, mg/kg BW. 
 #' @param dosing.matrix Vector of dosing times or a matrix consisting of two
 #' columns or rows named "dose" and "time" containing the time and amount, in
 #' mg/kg BW, of each dose. With the gas pbtk model, dosing.matrix is set to 
 #' specify forcing concentrations to the integrator, either in combination 
 #' with eventdata or on its own. 
-#' @param forcings Manual input of 'forcings' data series argument for ode
+#' @param forcings Manual input of "forcings" data series argument for ode
 #' integrator, defaults to NULL
 #' @param exp.start.time Start time in specifying forcing exposure series,
 #' default 0. 
-#' @param exp.conc Specified inhalation exposure concentration for use in assembling
-#' 'forcings' data series argument for integrator. Defaults to uM/L 
-#' @param period For use in assembling forcing function data series 'forcings'
+#' @param exp.conc Specified inhalation exposure concentration for use in 
+#' assembling "forcings" data series argument for integrator. Defaults to
+#' uM, in line with output.units
+#' @param period For use in assembling forcing function data series "forcings"
 #' argument, specified in hours
 #' @param exp.duration For use in assembling forcing function data 
 #' series 'forcings' argument, specified in hours
@@ -94,7 +95,7 @@
 #' @param recalc.blood2plasma Recalculates the ratio of the amount of chemical
 #' in the blood to plasma using the input parameters, calculated with
 #' hematocrit, Funbound.plasma, and Krbc2pu.
-#' @param recalc.clearance Recalculates the the hepatic clearance
+#' @param recalc.clearance Recalculates the hepatic clearance
 #' (Clmetabolism) with new million.cells.per.gliver parameter.
 #' @param adjusted.Funbound.plasma Uses adjusted Funbound.plasma when set to
 #' TRUE along with partition coefficients calculated with this value.
@@ -166,7 +167,7 @@ solve_gas_pbtk <- function(chem.name = NULL,
                            doses.per.day = NULL,
                            dose = NULL, #Assume single dose is in mg/kg BW/day
                            dosing.matrix = NULL,
-                           forcings = NULL, 
+                           forcings = NULL,
                            exp.start.time = 0, #default starting time in specifying forcing exposure
                            exp.conc = 1, #default exposure concentration for forcing data series
                            period = 24, 
@@ -193,8 +194,6 @@ solve_gas_pbtk <- function(chem.name = NULL,
                            VT = 0.75,
                            VD = 0.15,
                            ...)
-
-
 {
   
   #Screen against error in user's specification of forcing function timing
@@ -207,10 +206,10 @@ solve_gas_pbtk <- function(chem.name = NULL,
   #Screen against case in which forcing function is specified, but output.units
   #are specified as other than 'uM'. Units of forcing function exposure 
   #concentration are only supported as 'uM' for now.
-  if ((!is.null(forcings) | exp.conc > 0) & tolower(output.units) != 'um') {
-    stop('Forcings exposure data series not yet supported 
-         in units other than uM.')
-  }
+  #if ((!is.null(dosing.matrix) | exp.conc > 0) & tolower(output.units) != 'um') {
+    #stop('Forcings exposure data series not yet supported 
+      #   in units other than uM.')
+  #}
   
   #Look up the chemical name/CAS to get some info about the chemical in
   #question and screen it for relevance of its logHenry value. Should not
@@ -245,9 +244,11 @@ solve_gas_pbtk <- function(chem.name = NULL,
   
     #Screen for compatible input that goes on to specify forcing function data series. 
   if(is.null(forcings)) {
+  
+  
     if (exp.duration > period){
-      stop('If not specifying \'forcings\' data series explicitly, additional arguments are needed
-      to generate a \'forcings\' argument with a cyclic exposure pattern across the simulation:
+      stop('If not specifying \'dose.matrix\' data series explicitly, additional arguments are needed
+      to generate a \'dose.matrix\' argument with a cyclic exposure pattern across the simulation:
       exp.conc, period, exp.start.time, exp.duration, and days simulated.')
     }
     period <- period/24 #convert time period in hours to days
@@ -257,14 +258,30 @@ solve_gas_pbtk <- function(chem.name = NULL,
     #certain periodicity and exposure concentration in default case, used if 
     #the 'forcings' argument is not otherwise specified.
     forcing <- function(exp.conc, period, exp.start.time, exp.duration, days) {
+      #Provide for case in which forcing functionality is effectively turned off
+      if (exp.conc == 0) {
+        conc.matrix = NULL
+      } else {
       Nrep <- ceiling((days - exp.start.time)/period) 
       times <- rep(c(exp.start.time, exp.duration), Nrep) + rep(period * (0:(Nrep - 1)), rep(2, Nrep))
       y  <- rep(c(exp.conc,0), Nrep)
       conc.matrix = cbind(times,y)
+      }
       return(conc.matrix)
     }
     forcings = forcing(exp.conc, period, exp.start.time = 0, exp.duration, days) 
   }
+      
+      #Comment out tentative alternate scheme to forcings for now
+      ###
+    #Nrep <- ceiling((days - exp.start.time)/period)
+# We want the start and stop timeS:
+    #time <- sort(c(period * (0:(Nrep - 1)), # Start times
+      #period * (0:(Nrep - 1))+exp.duration)) # End times
+    #dose  <- rep(c(exp.conc,0), Nrep)
+    #dosing.matrix = cbind(dose,time)
+      ###
+  
   
   #Now make call to solve_model with gas model specific arguments configured 
   out <- solve_model(
@@ -311,15 +328,3 @@ solve_gas_pbtk <- function(chem.name = NULL,
   return(out)
 }
 
-
-
-
-
-
-
-
-
-
-
-
-
